/**
 * A function that behaves somewhat similar to jQuery,
 * without jQuery.
 */
function _$(selector) {
    let elements = document.querySelectorAll(selector);
    let mergedDatasets = {};
    for(let element of elements) {
        for(let property in element.dataset) {
            mergedDatasets[property] = element.dataset[property];
        }
    }

    return {
        on: function(eventName, eventListener) {
            for(let element of elements) {
                element.addEventListener(eventName, eventListener.bind(element));
            }
        },
        dataset: mergedDatasets,
        hide: function() {
            for(let element of elements) {
                element.classList.add("hidden");
            }
        },
        show: function() {
            for(let element of elements) {
                element.classList.remove("hidden");
            }
        },
        hasClass: function(cls) {
            if(!elements) {
                return false;
            }
            for(let element of elements) {
                if(!element.classList.contains(cls)) {
                    return false;
                }
            }
            return true;
        },
        each: function(consumer) {
            for(let element of elements) {
                consumer(element);
            }
        },
        click: function() {
            for(let element of elements) {
                element.click();
            }
        }
    };
}
