<?php
/**
 * Template Name: Landing Page
 *
 * Template for the landing page (= "home page", "start page"). WordPress
 * identifies this file by its "Template Name", which can be whatever you want.
 * After creating a page in the WordPress admin area, you can select this
 * template from a list of templates by its name.
 */

get_header();

function is_german() {
    return str_starts_with(get_bloginfo('language'), 'de');
}
?>
<main class="landing">
    <header>
        <h1><?php bloginfo('name');?></h1>
        <h2><?php bloginfo('description');?></h2>
    </header>
    <section class="ticker">
        <?php the_content(); ?>
    </section>
    <section class="news">
        <?php 
        // Formulate a query for all posts that are displayed on the "blog" page
        if (is_german()) {
            $the_query = new WP_Query("pagename=blog"); 
        } else {
            $the_query = new WP_Query("pagename=blog-2"); 
        }
        ?>

        <?php if ($the_query->have_posts()): ?>
            <?php 
                // Extract the first result from the query. From now on, all the_... methods
                // will use the data from this post
                $the_query->the_post(); 
            ?>

            <article>
                <header>
                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                </header>
                <div class="content">
                    <?php the_excerpt(); ?>
                </div>
            </article>
        <?php endif; ?>

        <aside>
            <ul>
                <?php for($i = 0; $i < 3 && $the_query->have_posts(); $i++): ?>
                    <?php $the_query->the_post(); ?>
                    <li><a href="<?php the_permalink(); ?>" class="headinglike"><?php the_title(); ?></a></li>
                <?php endfor; ?>
            </ul>

            <?php wp_reset_postdata(); ?>

            <div class="more">
                <a href="<?php echo home_url()."/blog/"; ?>"><?php
                    if (is_german()) {
                        echo "Ältere Posts...";
                    } else {
                        echo "older posts...";
                    }
                ?></a>
            </div>
        </aside>
    </section>
    <section class="varia">
        <ul class="seamless box-links">
            <?php if (is_german()): ?>
                <li>Technische Angebote der Fachschaft und nützliche Links findet ihr im <a href="https://fachschaft.cl.uni-heidelberg.de/portal">Portal</a>.</li>
                <li>Zögert nicht, bei Fragen und Problemen mit uns jederzeit <a href="/kontakt/">Kontakt</a> aufzunehmen.</li>
                <li>Außerdem könnt ihr uns auf <a href="https://www.instagram.com/fs.coli">Instagram</a> folgen, wenn ihr wollt.</li>
            <?php else: ?>
                <li>You can find our technical services and useful links via our <a href="https://fachschaft.cl.uni-heidelberg.de/portal">portal</a>.</li>
                <li>Don't hesitate to <a href="/en/contact/">contact</a> us at any time if you have questions or concerns.</li>
                <li>Furthermore, you can follow us on <a href="https://www.instagram.com/fs.coli">Instagram</a>, if you want to.</li>
            <?php endif; ?>
        </ul>

        <p>
            <?php if (is_german()): ?>
                Ansonsten könnt ihr uns auch einfach irgendwo auf dem Campus abfangen. Es gibt kein Entkommen!
            <?php else: ?>
                You can also just approach us on campus. There is no escape!
            <?php endif; ?>
        </p>
    </section>
</main>
<?php get_footer();?>
